# Cohort

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**name** | **str** |  | [optional] 
**model_id** | **str** |  | [optional] 
**train_cohort_id** | **str** |  | [optional] 
**cohort_windows** | [**list[CohortWindow]**](CohortWindow.md) |  | 
**organization_id** | **str** |  | 
**organization** | [**Organization**](Organization.md) |  | [optional] 
**datasets** | [**list[Dataset]**](Dataset.md) |  | [optional] 
**model** | [**Model**](Model.md) |  | [optional] 
**model_jobs** | [**list[ModelJob]**](ModelJob.md) |  | [optional] 
**train_cohort** | [**Cohort**](Cohort.md) |  | [optional] 
**prediction_cohorts** | [**list[Cohort]**](Cohort.md) |  | [optional] 
**last_updated_by** | **str** |  | [optional] 
**created_by** | **str** |  | [optional] 
**created_at** | **datetime** |  | [optional] 
**updated_at** | **datetime** |  | [optional] 
**archived_at** | **datetime** |  | [optional] 
**revised_at** | **datetime** |  | [optional] 
**version** | **float** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

